@@ -1,4 +1,4 @@
-package Pcore::Nginx v1.1.3;
+package Pcore::Nginx v1.2.0;
 
 use Pcore -dist, -class, -try;
 
@@ -34,7 +34,7 @@ sub _build_vhost_dir ($self) {
 sub run ($self) {
     my $params = {
         pid                => $self->conf_dir . 'nginx.pid',
-        mime_types         => $ENV->share->get('/data/nginx/mime.types'),
+        mime_types         => $self->conf_dir . 'mime.types',
         error_log          => $self->data_dir . 'nginx-error.log',
         geoip_country_path => $ENV->share->get('/data/geoip_country.dat') // undef,
         geoip_city_path    => $ENV->share->get('/data/geoip_city.dat') // undef,
@@ -42,6 +42,13 @@ sub run ($self) {
         ssl_dhparam        => $ENV->share->get('/data/nginx/dhparam-4096.pem'),
     };
 
+    my $mime_types = P->cfg->load( $ENV->share->get('data/mime.json') )->{suffix};
+    for my $suffix ( keys $mime_types->%* ) {
+        $mime_types->{$suffix} = [ $mime_types->{$suffix} ] if ref $mime_types->{$suffix} ne 'ARRAY';
+    }
+
+    P->file->write_text( $self->conf_dir . 'mime.types', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/mime.types', { mime_types => $mime_types } ) );
+
     P->file->write_text( $self->conf_dir . 'conf.nginx', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/conf.nginx', $params ) );
 
     P->file->write_text( $self->conf_dir . 'ssl.nginx', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/ssl.nginx', $params ) );
